pub struct InsertChunk {
pub idx: u16,
pub data: Vec<u8>,
}Expand description
Instruction.
Fields
idx: u16data: Vec<u8>Trait Implementations
Sourceimpl BorshDeserialize for InsertChunk
impl BorshDeserialize for InsertChunk
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for InsertChunk
impl BorshSerialize for InsertChunk
Sourceimpl Discriminator for InsertChunk
impl Discriminator for InsertChunk
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for InsertChunk
impl InstructionData for InsertChunk