pub struct Bitmap {
pub num_chunks: u16,
pub map: [u8; 256],
}Fields
num_chunks: u16map: [u8; 256]Implementations
Sourceimpl Bitmap
impl Bitmap
pub fn new(number_of_chunks: u16) -> Self
Sourcepub fn test_and_set(&mut self, idx: u16) -> Result<(), ErrorCode>
pub fn test_and_set(&mut self, idx: u16) -> Result<(), ErrorCode>
Mark the bit corresponding to the given index and return whether it was already set, panicking if it is out of bounds
Panicking is the “correct” behavior since it will cause the Solana tx to revert
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Check if all bits are set to 1.