Nitro DA Blober
The Blober program is an on-chain Solana program which stores data commitments on-chain and optimizes costs and throughput of having data availability on Solana.
Re-exports
pub use constants::*;pub use instructions::*;pub use state::*;
Modules
- accounts
- An Anchor generated module, providing a set of structs
mirroring the structs deriving
Accounts, where each field is aPubkey. This is useful for specifying accounts for a client. - blober
- constants
- error
- instruction
- An Anchor generated module containing the program’s set of
instructions, where each method handler in the
#[program]mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when speciying instructions on a client. - instructions
- program
- Module representing the program.
- state
Constants
- ID_
CONST - Const version of
ID
Statics
- ID
- The static program ID
Functions
- check_
id - Confirms that a given pubkey is equivalent to the program ID
- compute_
blob_ digest - Computes a blob digest of all the chunks of a blob.
- entry
- The Anchor codegen exposes a programming model where a user defines
a set of methods inside of a
#[program]module in a way similar to writing RPC request handlers. The macro then generates a bunch of code wrapping these user defined methods into something that can be executed on Solana. - entrypoint⚠
- Safety
- find_
blob_ address - Retrieves the PDA address of a blob account to store chunks and digest the data.
- find_
blober_ address - Retrieves the PDA address of a blober account to store digests and finalize blobs.
- hash_
blob - Computes the hashed state of a blob account.
- hash_
leaf - Hashes a single chunk on top of the previous hash.
- id
- Returns the program ID
- id_
const - Const version of
ID - merge_
hashes - Merges two hashes into a single one. Used when there are multiple blobs to finalize in the same slot.